import traceback
from asyncio.exceptions import TimeoutError

import orjson
from httpx import ConnectTimeout, PoolTimeout
from loguru import logger

from ..config import hikari_config
from ..HttpClient_Pool import get_client_yuyuko, recreate_client_yuyuko
from ..model import Hikari_Model
from .publicAPI import get_ClanIdByName


async def get_ClanRank(hikari: Hikari_Model) -> Hikari_Model:
    """查询公会基础信息"""
    try:
        if hikari.Status == 'init':
            if hikari.Input.Search_Type == 3:
                clanList = await get_ClanIdByName(hikari.Input.Server, hikari.Input.ClanName)
                if clanList:
                    if len(clanList) < 2:
                        hikari.Input.ClanId = clanList[0]['clanId']
                    else:
                        hikari.Input.Select_Data = clanList
                        hikari.set_template_info('select-clan.html', 360, 100)
                        return hikari.wait(clanList)
                else:
                    return hikari.failed('找不到军团，请确认军团名是否正确')
        elif hikari.Status == 'wait':
            if hikari.Input.Select_Data and hikari.Input.Select_Index and hikari.Input.Select_Index <= len(hikari.Input.Select_Data):
                hikari.Input.ClanId = hikari.Input.Select_Data[hikari.Input.Select_Index - 1]['clanId']
            else:
                return hikari.error('请选择有效的序号')
        else:
            return hikari.error('当前请求状态错误')

        # if hikari.Input.Search_Type == 3:
        #    is_cache = await check_yuyuko_cache(hikari.Input.Server, hikari.Input.AccountId)
        # else:
        #    is_cache = await check_yuyuko_cache(hikari.Input.Platform, hikari.Input.PlatformId)
        # if is_cache:
        #    logger.success('上报数据成功')
        # else:
        #    logger.success('跳过上报数据，直接请求')

        url = f'{hikari_config.yuyuko_url}/public/wows/clan/info'
        if hikari.Input.Search_Type == 3:
            params = {'server': hikari.Input.Server, 'accountId': hikari.Input.ClanId}
        else:
            params = {'server': hikari.Input.Platform, 'accountId': hikari.Input.PlatformId}
        client_yuyuko = await get_client_yuyuko()
        resp = await client_yuyuko.get(url, params=params, timeout=10)
        result = orjson.loads(resp.content)
        hikari.Output.Yuyuko_Code = result['code']

        if result['code'] == 200 and result['data']:
            latest_season = str(result['data']['clanLeagueInfo']['lastSeason'])
            result['data']['latest_season'] = latest_season
            hikari.set_template_info('wws-clan.html', 1200, 100)
            return hikari.success(result['data'])
        elif result['code'] == 403:
            return hikari.failed(f"{result['message']}\n请先绑定账号")
        elif result['code'] == 500:
            return hikari.failed(f"{result['message']}\n这是服务器问题，请联系雨季麻麻")
        else:
            return hikari.failed(f"{result['message']}")
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return hikari.error('请求超时了，请过会儿再尝试哦~')
    except PoolTimeout:
        await recreate_client_yuyuko()
        return hikari.error('连接池异常，请尝试重新查询~')
    except Exception:
        logger.error(traceback.format_exc())
        return hikari.error('wuwuwu出了点问题，请联系麻麻解决')



import re
import traceback
from dataclasses import dataclass
from pathlib import Path
from typing import Tuple

dir_path = Path(__file__).parent
template_path = dir_path / 'Template'
__version__ = '1.0.6.2'


@dataclass
class matching:
    keywords: Tuple[str, ...]
    match_keywords: str


nations = [
    matching(('commonwealth', '英联邦'), 'Commonwealth'),
    matching(('europe', '欧洲'), 'Europe'),
    matching(('france', '法国'), 'France'),
    matching(('germany', '德国'), 'Germany'),
    matching(('italy', '意大利'), 'Italy'),
    matching(('japan', '日本'), 'Japan'),
    matching(('pan_america', '泛美'), 'Pan_America'),
    matching(('pan_asia', '泛亚'), 'Pan_Asia'),
    matching(('uk', '英国', 'United_Kingdom'), 'United_Kingdom'),
    matching(('usa', '美国'), 'USA'),
    matching(('ussr', '苏联'), 'Russia'),
    matching(('netherlands', '荷兰'), 'Netherlands'),
    matching(('spain', '西班牙'), 'Spain'),
]

shiptypes = [
    matching(('Cruiser', '巡洋舰', '巡洋', 'CA'), 'Cruiser'),
    matching(('Battleship', '战列舰', '战列', 'BB'), 'Battleship'),
    matching(('Destroyer', '驱逐舰', '驱逐', 'DD'), 'Destroyer'),
    matching(('Submarine', '潜艇', 'SS'), 'Submarine'),
    matching(('Auxiliary', '辅助航母', 'DD'), 'Auxiliary'),
    matching(('AirCarrier', '航空母舰', '航母', 'CV'), 'AirCarrier'),
]

levels = [
    matching(('1', '1级', '一级', '一'), '1'),
    matching(('2', '2级', '二级', '二'), '2'),
    matching(('3', '3级', '三级', '三'), '3'),
    matching(('4', '4级', '四级', '四'), '4'),
    matching(('4', '4级', '四级', '四'), '4'),
    matching(('5', '5级', '五级', '五'), '5'),
    matching(('6', '6级', '六级', '六'), '6'),
    matching(('7', '7级', '七级', '七'), '7'),
    matching(('8', '8级', '八级', '八'), '8'),
    matching(('9', '9级', '九级', '九'), '9'),
    matching(('10', '10级', '十级', '十'), '10'),
    matching(('11', '11级', '十一级', '十一'), '11'),
]

servers = [
    matching(('asia', '亚服', 'asian'), 'asia'),
    matching(('eu', '欧服', 'europe'), 'eu'),
    matching(('na', '美服', 'NorthAmerican'), 'na'),
    matching(('ru', '俄服', 'Russia'), 'ru'),
    matching(('cn', '国服', 'china'), 'cn'),
]

tiers = ['Ⅰ', 'Ⅱ', 'Ⅲ', 'Ⅳ', 'Ⅴ', 'Ⅵ', 'Ⅶ', 'Ⅷ', 'Ⅸ', 'Ⅹ', 'Ⅺ']

number_url_homes = {
    'asia': 'https://asia.wows-numbers.com',
    'eu': 'https://wows-numbers.com',
    'na': 'https://na.wows-numbers.com',
    'ru': 'https://ru.wows-numbers.com',
    'cn': '',
}

nb2_file = [
    {'name': 'bot.py', 'url': 'https://raw.fastgit.org/benx1n/HikariBot/master/bot.py'},
    {'name': '.env', 'url': 'https://raw.fastgit.org/benx1n/HikariBot/master/.env'},
    {
        'name': 'pyproject.toml',
        'url': 'https://raw.fastgit.org/benx1n/HikariBot/master/pyproject.toml',
    },
]

pr_select = [
    {'value': 0, 'name': '还需努力', 'englishName': 'Bad', 'color': '#f44336'},
    {'value': 750, 'name': '低于平均', 'englishName': 'Below Average', 'color': '#FF9800'},
    {'value': 1100, 'name': '平均水平', 'englishName': 'Average', 'color': '#FFC107'},
    {'value': 1350, 'name': '好', 'englishName': 'Good', 'color': '#8BC34A'},
    {'value': 1550, 'name': '很好', 'englishName': 'Very Good', 'color': '#4CAF50'},
    {'value': 1750, 'name': '非常好', 'englishName': 'Great', 'color': '#00BCD4'},
    {'value': 2100, 'name': '大佬水平', 'englishName': 'Unicum', 'color': '#9C27B0'},
    {'value': 2450, 'name': '神佬水平', 'englishName': 'Super Unicum', 'color': '#673AB7'},
]

color_data = {
    'Bad': '#F44336',
    'Below Average': '#FF9800',
    'Average': '#FFC107',
    'Good': '#8BC34A',
    'Very Good': '#4CAF50',
    'Great': '#00BCD4',
    'Unicum': '#9C27B0',
    'Super Unicum': '#673AB7',
}


async def set_render_params(List):
    try:
        result = {'template_path': template_path, 'data': List}
        return result
    except Exception:
        traceback.print_exc()


async def select_prvalue_and_color(pr):
    describe, color = None, None
    if pr:
        for select in pr_select:
            if pr > select['value']:
                describe = select['name']
                color = select['color']
    return describe, color


async def set_ShipRank_Numbers(data, server, shipId):
    try:
        info_list = []
        for each in data:
            index = int(each.select('td')[0].string)
            clan_name = each.select('td[style="text-align: left;  "] a')
            if len(clan_name) > 1:
                tag = clan_name[0].string.replace('[', '').replace(']', '')
                userName = clan_name[1].string
                url = clan_name[1].attrs['href']
            else:
                tag = None
                userName = clan_name[0].string
                url = clan_name[0].attrs['href']
            accountId = await search_accountId(url)
            battles = int(each.select('td span')[0].string.replace(' ', ''))
            pr = int(each.select('td span')[1].string.replace(' ', ''))
            prColor = await search_color(each.select('td span')[1].attrs['style'])
            wins = float(each.select('td span')[2].string.replace('%', ''))
            winsColor = await search_color(each.select('td span')[2].attrs['style'])
            frags = float(each.select('td span')[3].string)
            fragsColor = await search_color(each.select('td span')[3].attrs['style'])
            maxFrags = int(each.select('td span')[4].string)
            damage = int(each.select('td span')[5].string.replace(' ', ''))
            damageColor = await search_color(each.select('td span')[5].attrs['style'])
            maxDamage = int(each.select('td span')[6].string.replace(' ', ''))
            xp = int(each.select('td span')[7].string.replace(' ', ''))
            maxXp = int(each.select('td span')[8].string.replace(' ', ''))
            planesDestroyed = float(each.select('td span')[9].string)
            planesDestroyedColor = await search_color(each.select('td span')[9].attrs['style'])
            maxPlanesDestroyed = int(each.select('td span')[10].string)
            info = {
                'accountId': accountId,
                'battles': battles,
                'damage': damage,
                'damageColor': damageColor,
                'frags': frags,
                'fragsColor': fragsColor,
                'index': index,
                'maxDamage': maxDamage,
                'maxFrags': maxFrags,
                'maxPlanesDestroyed': maxPlanesDestroyed,
                'maxXp': maxXp,
                'planesDestroyed': planesDestroyed,
                'planesDestroyedColor': planesDestroyedColor,
                'pr': pr,
                'prColor': prColor,
                'server': server,
                'shipId': shipId,
                'wins': wins,
                'winsColor': winsColor,
                'xp': xp,
                'tag': tag,
                'userName': userName,
            }
            info_list.append(info)
        return info_list

    except Exception:
        traceback.print_exc()
        return None


async def set_clanRecord_params():
    return


async def search_accountId(str):
    try:
        match = re.search(r'/player/(.*?),', str)
        if match:
            return int(match.group(1).strip())
        else:
            return None
    except Exception:
        traceback.print_exc()
        return None


async def search_color(str):
    try:
        match = re.search(r'color:(.*?);', str)
        if match:
            return match.group(1).strip()
        else:
            return None
    except Exception:
        traceback.print_exc()
        return None


async def set_damageColor(type, value):
    try:
        if type == 'Destroyer':
            if not value or value < 33000:
                return color_data['Bad']
            elif value < 40000:
                return color_data['Good']
            elif value < 55000:
                return color_data['Great']
            elif value < 64000:
                return color_data['Unicum']
            else:
                return color_data['Super Unicum']
        elif type == 'Cruiser':
            if not value or value < 47000:
                return color_data['Bad']
            elif value < 55000:
                return color_data['Good']
            elif value < 83000:
                return color_data['Great']
            elif value < 95000:
                return color_data['Unicum']
            else:
                return color_data['Super Unicum']
        elif type == 'AirCarrier':
            if not value or value < 60000:
                return color_data['Bad']
            elif value < 71000:
                return color_data['Good']
            elif value < 84000:
                return color_data['Great']
            elif value < 113000:
                return color_data['Unicum']
            else:
                return color_data['Super Unicum']
        elif type == 'BattleShip':
            if not value or value < 64000:
                return color_data['Bad']
            elif value < 72000:
                return color_data['Good']
            elif value < 97000:
                return color_data['Great']
            elif value < 108000:
                return color_data['Unicum']
            else:
                return color_data['Super Unicum']
    except Exception:
        traceback.print_exc()
        return None


async def set_winColor(value):
    try:
        if not value or value < 45:
            return color_data['Bad']
        elif value < 50:
            return color_data['Below Average']
        elif value < 55:
            return color_data['Average']
        elif value < 60:
            return color_data['Good']
        elif value < 65:
            return color_data['Great']
        elif value < 70:
            return color_data['Unicum']
        else:
            return color_data['Super Unicum']
    except Exception:
        traceback.print_exc()
        return None


async def set_upinfo_color(value):
    try:
        if not value or value < 0:
            return color_data['Bad']
        elif value > 0:
            return color_data['Good']
        else:
            return None
    except Exception:
        traceback.print_exc()
        return None



import html
import random
import re
import time
import traceback
from datetime import datetime

from loguru import logger

from .command_select import select_command
from .data_source import levels, nations, servers, shiptypes
from .game.ban_search import get_BanInfo
from .game.box_check import check_christmas_box
from .game.roll import roll_ship
from .game.sx import get_sx_info
from .model import Hikari_Model
from .moudle.publicAPI import get_ship_name
from .moudle.wws_bind import change_BindInfo, delete_BindInfo, get_BindInfo, set_BindInfo, set_special_BindInfo
from .moudle.wws_clan import get_ClanInfo
from .moudle.wws_cwrank import get_CwRank
from .moudle.wws_info import get_AccountInfo
from .moudle.wws_real_game import add_listen_list, delete_listen_list
from .moudle.wws_recent import get_RecentInfo
from .moudle.wws_recents import get_RecentsInfo
from .moudle.wws_ship_info import get_ShipInfo
from .moudle.wws_ship_recent import get_ShipRecent
from .moudle.wws_shiprank import get_ShipRank
from .utils import match_keywords


async def analyze_command(hikari: Hikari_Model) -> Hikari_Model:
    try:
        if hikari.Status == 'init':  # 状态为init时才解析
            if not hikari.Input.Command_Text:
                return hikari.error('请发送wws help查看帮助')
            if random.randint(1, 1000) == 1:
                return hikari.error('一天到晚惦记你那b水表，就nm离谱')
            hikari.Input.Command_Text = html.unescape(str(hikari.Input.Command_Text)).strip()
            hikari = await extract_with_special_name(hikari)
            hikari.Function, hikari.Input.Command_List = await select_command(hikari.Input.Command_List)
            if hikari.Input.AccountName:
                hikari.Input.Command_List.insert(0, hikari.Input.AccountName)
            hikari = await extract_with_me_or_at(hikari)
            hikari = await extract_with_function(hikari)
        return hikari
    except Exception:
        logger.error(traceback.format_exc())
        return hikari.error('解析指令时发生错误，请确认输入参数无误')


async def extract_with_special_name(hikari: Hikari_Model) -> Hikari_Model:
    try:
        match = re.search(r'(\(|（)(.*?)(\)|）)', hikari.Input.Command_Text)  # 是否存在（），存在则需提取出来
        if match:
            hikari.Input.AccountName = match.group(2)
            hikari.Input.Command_List = hikari.Input.Command_Text.replace(match.group(0), '').split()
        else:
            hikari.Input.Command_List = hikari.Input.Command_Text.split()
        return hikari
    except Exception:
        logger.error(traceback.format_exc())
        return hikari.error('解析指令时发生错误，请确认输入参数无误')


async def extract_with_me_or_at(hikari: Hikari_Model) -> Hikari_Model:
    try:
        if hikari.UserInfo.Platform in ['QQ', 'QQ_CHANNEL', 'QQ_OFFICIAL']:
            # 频道无其他参数时默认me
            if hikari.UserInfo.Platform == 'QQ_OFFICIAL':
                analyze_command_list = hikari.Input.Command_List.copy()
                analyze_server, analyze_command_list = await match_keywords(analyze_command_list, servers)
                if not analyze_server:
                    hikari.Input.Search_Type = 1
                    hikari.Input.Platform = hikari.UserInfo.Platform
                    hikari.Input.PlatformId = hikari.UserInfo.PlatformId
            for i in hikari.Input.Command_List:
                if str(i).lower() == 'me':
                    hikari.Input.Search_Type = 1
                    hikari.Input.Platform = hikari.UserInfo.Platform
                    hikari.Input.PlatformId = hikari.UserInfo.PlatformId
                    hikari.Input.Command_List.remove(i)
                    break
                if hikari.UserInfo.Platform == 'QQ':
                    match = re.search(r'CQ:at,qq=(\d+)', i)
                elif hikari.UserInfo.Platform == 'QQ_CHANNEL':
                    match = re.search(r'<@!(\d+)', i)
                else:
                    match = None
                if match:
                    hikari.Input.Search_Type = 2
                    hikari.Input.Platform = hikari.UserInfo.Platform
                    hikari.Input.PlatformId = str(match.group(1))
                    hikari.Input.Command_List.remove(i)
                    break
        return hikari
    except Exception:
        logger.error(traceback.format_exc())
        return hikari.error('解析指令时发生错误，请确认输入参数无误')


async def extract_with_function(hikari: Hikari_Model) -> Hikari_Model:  # noqa: PLR0915
    try:
        if hikari.Function in [get_AccountInfo, get_RecentInfo, get_RecentsInfo, get_ShipInfo, get_ShipRecent]:
            hikari.Input.Recent_Date = time.strftime('%Y-%m-%d', time.localtime())
            if hikari.Function == get_RecentInfo and datetime.now().hour < 7:
                hikari.Input.Recent_Day = 1
            # 判断day,date
            delete_list = []
            for i in hikari.Input.Command_List:
                if str(i).isdigit() and len(i) <= 3:
                    hikari.Input.Recent_Day = int(i)
                    delete_list.append(i)
                try:
                    time.strptime(str(i), '%Y-%m-%d')
                    hikari.Input.Recent_Date = str(i)
                    delete_list.append(i)
                    hikari.Input.Recent_Day = 0  # 存在date时day强制为0
                except ValueError:
                    continue
            # 移除day,date
            for each in delete_list:
                hikari.Input.Command_List.remove(each)
            if hikari.Function in [get_AccountInfo, get_RecentInfo, get_RecentsInfo]:
                if hikari.Input.Search_Type == 3:
                    if len(hikari.Input.Command_List) == 2:
                        hikari.Input.Server, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, servers)
                        if hikari.Input.Server:
                            hikari.Input.AccountName = str(hikari.Input.Command_List[0])
                        else:
                            return hikari.error('服务器名输入错误')
                    else:
                        return hikari.error('您似乎准备用游戏昵称查询水表，请检查参数中是否包含服务器和游戏昵称，以空格分隔，顺序不限')
            elif hikari.Function in [get_ShipInfo, get_ShipRecent]:
                if hikari.Input.Search_Type == 3:
                    if len(hikari.Input.Command_List) == 3:
                        hikari.Input.Server, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, servers)
                        if hikari.Input.Server:
                            hikari.Input.AccountName = str(hikari.Input.Command_List[0])
                            hikari.Input.ShipInfo.Ship_Name_Cn = str(hikari.Input.Command_List[1])
                        else:
                            return hikari.error('服务器参数输入错误')
                    else:
                        return hikari.error('您似乎准备用服务器+昵称查询单船战绩，请检查参数是否缺少或溢出，以空格分隔，顺序不限')
                elif len(hikari.Input.Command_List) == 1:
                    hikari.Input.ShipInfo.Ship_Name_Cn = str(hikari.Input.Command_List[0])
                else:
                    return hikari.error('您似乎准备用me或@查询单船战绩，请检查参数是否缺少或溢出，以空格分隔，顺序不限')
        elif hikari.Function in [get_BindInfo, set_BindInfo, set_special_BindInfo, change_BindInfo, delete_BindInfo]:
            if hikari.Function == get_BindInfo and hikari.Input.Search_Type not in [1, 2]:
                return hikari.error('参数似乎出了问题呢，请使用me或@群友')
            elif hikari.Function in [set_BindInfo, set_special_BindInfo]:
                if hikari.Input.Search_Type != 3 and len(hikari.Input.Command_List) != 2:
                    return hikari.error('参数似乎输错了呢，请确保后面跟随服务器+游戏昵称')
                else:
                    # 解析双参数内的AccountName和Server
                    hikari.Input.Server, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, servers)
                    if hikari.Input.Server:
                        # 普通绑定时剩余的参数为AccountName
                        if hikari.Function == set_BindInfo:
                            hikari.Input.AccountName = str(hikari.Input.Command_List[0])
                        # 特殊绑定时剩余的参数为AccountId
                        elif hikari.Function == set_special_BindInfo and hikari.Input.Command_List[0].isdigit():
                            hikari.Input.AccountId = int(hikari.Input.Command_List[0])
                        else:
                            return hikari.error('请在网页版复制正确的特殊绑定指令，地址：https://wows.mgaia.top')
                        # 绑定强制为当前平台账号
                        hikari.Input.Platform = hikari.UserInfo.Platform
                        hikari.Input.PlatformId = hikari.UserInfo.PlatformId
                    else:
                        return hikari.error('服务器名输入错误')
            elif hikari.Function in [change_BindInfo, delete_BindInfo]:
                if len(hikari.Input.Command_List) not in [0, 1]:
                    return hikari.error('请检查是否仅输入了要切换的序号，也可为空进入选择列表')
                # 检查是否带序号
                delete_list = []
                if len(hikari.Input.Command_List) == 1:
                    for i in hikari.Input.Command_List:
                        if str(i).isdigit() and len(i) <= 3:
                            hikari.Input.Select_Index = int(i)
                            delete_list.append(i)
                    for each in delete_list:
                        hikari.Input.Command_List.remove(each)
                # 切换删除绑定强制为当前平台账号
                hikari.Input.Platform = hikari.UserInfo.Platform
                hikari.Input.PlatformId = hikari.UserInfo.PlatformId
        elif hikari.Function in [get_BanInfo, get_sx_info, check_christmas_box]:
            if hikari.Input.Search_Type == 3:
                if len(hikari.Input.Command_List) == 2:
                    hikari.Input.Server, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, servers)
                    if hikari.Input.Server:
                        hikari.Input.AccountName = str(hikari.Input.Command_List[0])
                    elif hikari.Function == get_BanInfo and hikari.Input.Server != 'cn':
                        return hikari.error('服务器名输入错误,目前仅支持国服查询')
                else:
                    return hikari.error('您似乎准备用游戏昵称查询，请检查参数中是否包含服务器和游戏昵称，以空格分隔，顺序不限')
        elif hikari.Function in [get_ship_name, roll_ship]:
            hikari.Input.ShipInfo.Ship_Nation, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, nations)
            if not hikari.Input.ShipInfo.Ship_Nation and hikari.Function == get_ship_name:
                return hikari.error('请检查国家名是否正确')

            hikari.Input.ShipInfo.Ship_Type, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, shiptypes)
            if not hikari.Input.ShipInfo.Ship_Type and hikari.Function == get_ship_name:
                return hikari.error('请检查船只类别是否正确')

            hikari.Input.ShipInfo.Ship_Tier, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, levels)
            if not hikari.Input.ShipInfo.Ship_Tier and hikari.Function == get_ship_name:
                return hikari.error('请检查船只等级是否正确')
        elif hikari.Function in [get_ShipRank]:
            if len(hikari.Input.Command_List) == 2:
                hikari.Input.Server, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, servers)
                if hikari.Input.Server:
                    hikari.Input.ShipInfo.Ship_Name_Cn = str(hikari.Input.Command_List[0])
                else:
                    return hikari.error('服务器名输入错误')
            else:
                return hikari.error('请检查参数中是否包含服务器和船名，以空格分隔，顺序不限')
        elif hikari.Function in [add_listen_list]:
            if len(hikari.Input.Command_List) == 3:
                hikari.Input.Server, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, servers)
                if hikari.Input.Server:
                    hikari.Input.AccountName = str(hikari.Input.Command_List[0])
                else:
                    return hikari.error('服务器名输入错误')
            else:
                return hikari.error('请检查参数中是否包含服务器、游戏昵称、备注昵称，以空格分隔，顺序不限')
        elif hikari.Function in [delete_listen_list]:
            if len(hikari.Input.Command_List) == 1:
                if str(hikari.Input.Command_List[0]).isdigit() and len(hikari.Input.Command_List[0]) < 3:
                    hikari.Input.Select_Index = int(hikari.Input.Command_List[0])
                else:
                    return hikari.error('请确认输入序号是否正确')
            else:
                return hikari.error('请检查是否仅输入了要删除的监控序号')
        elif hikari.Function in [get_ClanInfo]:
            if hikari.Input.Search_Type == 3:
                if len(hikari.Input.Command_List) == 2:
                    hikari.Input.Server, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, servers)
                    if hikari.Input.Server:
                        hikari.Input.ClanName = str(hikari.Input.Command_List[0])
                    else:
                        return hikari.error('服务器名输入错误')
                else:
                    return hikari.error('您似乎准备用公会TAG查询水表，请检查参数中是否包含服务器和公会TAG，以空格分隔，顺序不限')
        elif hikari.Function in [get_CwRank]:
            hikari.Input.Server, hikari.Input.Command_List = await match_keywords(hikari.Input.Command_List, servers)
            delete_list = []
            if len(hikari.Input.Command_List) == 1:
                for i in hikari.Input.Command_List:
                    if str(i).isdigit() and len(i) <= 3:
                        hikari.Input.CwSeasonId = int(i)
                        delete_list.append(i)
                for each in delete_list:
                    hikari.Input.Command_List.remove(each)
            elif len(hikari.Input.Command_List) > 1:
                return hikari.error('您似乎准备查询CW排行榜，请确认是否仅输入了赛季和服务器，留空为最新赛季和全服')
        return hikari
    except Exception:
        logger.error(traceback.format_exc())
        return hikari.error('解析指令时发生错误，请确认输入参数无误')



# fmt: off
import traceback
from asyncio.exceptions import TimeoutError

import orjson
from httpx import ConnectTimeout, PoolTimeout
from loguru import logger

from ..HttpClient_Pool import get_client_yuyuko, recreate_client_yuyuko
from ..model import Hikari_Model
from .publicAPI import check_yuyuko_cache, get_AccountIdByName, get_ship_byName

# fmt: on


async def get_ShipRecent(hikari: Hikari_Model) -> Hikari_Model:
    """查询单船Recent"""
    try:
        if hikari.Status == 'init':
            shipList = await get_ship_byName(hikari.Input.ShipInfo.Ship_Name_Cn)
            if shipList:
                if len(shipList) < 2:
                    hikari.Input.ShipInfo = shipList[0]
                else:
                    hikari.Input.Select_Data = shipList
                    hikari.set_template_info('select-ship.html', 360, 100)
                    return hikari.wait(shipList)
            else:
                return hikari.failed('找不到船，请确认船名是否正确，可以使用【wws 查船名】查询船只中英文')
        elif hikari.Status == 'wait':
            if hikari.Input.Select_Data and hikari.Input.Select_Index and hikari.Input.Select_Index <= len(hikari.Input.Select_Data):
                hikari.Input.ShipInfo = hikari.Input.Select_Data[hikari.Input.Select_Index - 1]
            else:
                return hikari.error('请选择有效的序号')
        else:
            return hikari.error('当前请求状态错误')

        if hikari.Input.Search_Type == 3:
            hikari.Input.AccountId = await get_AccountIdByName(hikari.Input.Server, hikari.Input.AccountName)
            if not isinstance(hikari.Input.AccountId, int):
                return hikari.error(f'{hikari.Input.AccountId}')

        if hikari.Input.Search_Type == 3:
            is_cache = await check_yuyuko_cache(hikari.Input.Server, hikari.Input.AccountId)
        else:
            is_cache = await check_yuyuko_cache(hikari.Input.Platform, hikari.Input.PlatformId)
        if is_cache:
            logger.success('上报数据成功')
        else:
            logger.success('跳过上报数据，直接请求')

        url = 'https://recent.wows.shinoaki.com:8890/api/wows/recent/day/info'
        if hikari.Input.Search_Type == 3:
            params = {
                'server': hikari.Input.Server,
                'accountId': hikari.Input.AccountId,
                'dateTime': hikari.Input.Recent_Date,
                'day': hikari.Input.Recent_Day,
                'shipId': hikari.Input.ShipInfo.Ship_Id,
            }
        else:
            params = {
                'server': hikari.Input.Platform,
                'accountId': hikari.Input.PlatformId,
                'dateTime': hikari.Input.Recent_Date,
                'day': hikari.Input.Recent_Day,
                'shipId': hikari.Input.ShipInfo.Ship_Id,
            }

        client_yuyuko = await get_client_yuyuko()
        resp = await client_yuyuko.get(url, params=params, timeout=10)
        result = orjson.loads(resp.content)
        hikari.Output.Yuyuko_Code = result['code']

        if result['code'] == 200 and result['data']:
            hikari.set_template_info('wws-ship-recent.html', 800, 100)
            return hikari.success(result['data'])
        elif result['code'] == 403:
            return hikari.failed(f"{result['message']}\n请先绑定账号")
        elif result['code'] == 500:
            return hikari.failed(f"{result['message']}\n这是服务器问题，请联系雨季麻麻")
        else:
            return hikari.failed(f"{result['message']}")
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return hikari.error('请求超时了，请过会儿再尝试哦~')
    except PoolTimeout:
        await recreate_client_yuyuko()
        return hikari.error('连接池异常，请尝试重新查询~')
    except Exception:
        logger.error(traceback.format_exc())
        return hikari.error('wuwuwu出了点问题，请联系麻麻解决')



from dataclasses import dataclass
from typing import List, Protocol, Tuple, runtime_checkable

from .game.ban_search import get_BanInfo
from .game.box_check import check_christmas_box
from .game.help import async_update_template, check_version, get_help

# from .game.ocr import get_Random_Ocr_Pic
from .game.roll import roll_ship
from .game.sx import get_sx_info
from .moudle.publicAPI import get_ship_name
from .moudle.wws_bind import change_BindInfo, delete_BindInfo, get_BindInfo, set_BindInfo, set_special_BindInfo
from .moudle.wws_clan import get_ClanInfo
from .moudle.wws_clanrank import get_ClanRank
from .moudle.wws_cwrank import get_CwRank
from .moudle.wws_info import get_AccountInfo
from .moudle.wws_real_game import add_listen_list, delete_listen_list, get_diff_ship, get_listen_list, reset_config
from .moudle.wws_recent import get_RecentInfo
from .moudle.wws_recents import get_RecentsInfo

# from .moudle.wws_record import get_record
from .moudle.wws_ship_info import get_ShipInfo
from .moudle.wws_ship_recent import get_ShipRecent
from .moudle.wws_shiprank import get_ShipRank


@runtime_checkable
class Func(Protocol):
    async def __call__(self, **kwargs):
        ...


@dataclass
class command:
    keywords: Tuple[str, ...]  # 指令字段
    func: Func  # 匹配到的方法，为空进入二级指令匹配
    default_func: Func = None  # 二级指令未匹配到时返回选择的默认方法
    second_select: list = None  # 二级指令列表


ship_command_list = [
    command(('recent', '近期'), get_ShipRecent),
]

recent_command_list = [
    command(('ship', '单船'), get_ShipRecent),
]


rank_command_list = [
    command(('ship', '单船', '战舰'), get_ShipRank),
    command(('cw', '军团战', '公会战'), get_CwRank),
    command(('clan', '军团', '公会'), get_ClanRank),
]

clan_command_list = [
    command(('rank',), get_ClanRank),
]


first_command_list = [  # 同指令中越长的匹配词越靠前
    command(('check_version', '检查更新'), check_version),
    command(('更新样式',), async_update_template),
    command(('查询监控', '监控列表', '查询监听', '监听列表'), get_listen_list),
    command(('测试监控',), get_diff_ship),
    command(('添加监控',), add_listen_list),
    command(('删除监控',), delete_listen_list),
    command(('重置监控',), reset_config),
    command(('切换绑定', '更换绑定', '更改绑定'), change_BindInfo),
    command(('查询绑定', '绑定查询', '绑定列表', '查绑定'), get_BindInfo),
    command(('删除绑定',), delete_BindInfo),
    command(('特殊绑定',), set_special_BindInfo),
    command(('ship.rank', '单船排行榜', '战舰排行榜'), get_ShipRank),
    command(('cw.rank', '军团战排行榜', '公会战排行榜'), get_CwRank),
    command(('clan.rank', '军团排行榜', '公会排行榜'), get_ClanRank),
    command(('rank', '排行榜'), None, get_ShipRank, rank_command_list),
    command(('bind', '绑定', 'set'), set_BindInfo),
    command(('recents', '单场近期'), get_RecentsInfo),
    command(('recent', '近期'), None, get_RecentInfo, recent_command_list),
    command(('ship', '单船'), None, get_ShipInfo, ship_command_list),
    # command(("record", "历史记录"), None, get_record),
    command(('clan', '军团', '公会', '工会'), None, get_ClanInfo, clan_command_list),
    # command(("随机表情包",), get_Random_Ocr_Pic),
    command(('roll', '随机'), roll_ship),
    command(('sx', '扫雪'), get_sx_info),
    command(('ban', '封号记录'), get_BanInfo),
    command(('box', 'sd', '圣诞船池'), check_christmas_box),
    command(('搜船名', '查船名', '船名'), get_ship_name),
    command(('help', '帮助'), get_help),
]


async def findFunction_and_replaceKeywords(match_list, command_List, default_func) -> Tuple[command, List]:
    for com in command_List:
        for kw in com.keywords:
            for i, match_kw in enumerate(match_list):
                if match_kw.find(kw) + 1:
                    match_list[i] = str(match_kw).replace(kw, '')
                    if not match_list[i]:  # 为空时才删除，防止未加空格没有被split切割
                        match_list.remove('')
                    return com, match_list
    return (
        command(None, default_func, None),
        match_list,
    )


async def select_command(search_list) -> Tuple[Func, List]:
    command, search_list = await findFunction_and_replaceKeywords(search_list, first_command_list, get_AccountInfo)
    if command.func is None:
        command, search_list = await findFunction_and_replaceKeywords(search_list, command.second_select, command.default_func)
    return command.func, search_list



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['hikari_core',
 'hikari_core.Html_Render',
 'hikari_core.game',
 'hikari_core.moudle']

package_data = \
{'': ['*'],
 'hikari_core': ['Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/bind-list.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/cw-rank.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-clan.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/select-ship.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/ship-rank.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/text.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-ban.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-box-christmas.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-clan.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recent.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info-recents.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-info.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-personalRecord.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship-recent.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-ship.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-sx.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html',
                 'Template/wws-unban.html'],
 'hikari_core.Html_Render': ['templates/*']}

install_requires = \
['APScheduler>=3.10.1,<4.0.0',
 'aiofiles>=0.8.0',
 'asyncio>=3.4.3,<4.0.0',
 'beautifulsoup4>=4.12.2,<5.0.0',
 'httpx[http2]>=0.24.0',
 'jinja2>=3.0.0,<4.0.0',
 'json_tools>=0.4.1,<0.5.0',
 'loguru>=0.7.0,<0.8.0',
 'orjson>=3.8.11,<4.0.0',
 'playwright>=1.17.2',
 'pydantic>=1.10.7,<2.0.0']

setup_kwargs = {
    'name': 'hikari-core',
    'version': '1.0.6.2',
    'description': 'SDK for yuyuko,战舰世界yuyuko平台BOT SDK',
    'long_description': '# Hikari-core\nSDK for yuyuko API\n',
    'author': 'benx1n',
    'author_email': '1119809439@qq.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/wows-yuyuko/Hikari-core',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



import traceback
from asyncio.exceptions import TimeoutError

import orjson
from httpx import ConnectTimeout, PoolTimeout
from loguru import logger

from ..config import hikari_config
from ..HttpClient_Pool import get_client_yuyuko, recreate_client_yuyuko
from ..model import Hikari_Model


async def get_CwRank(hikari: Hikari_Model) -> Hikari_Model:
    """查询军团战排行榜"""
    try:
        if hikari.Status == 'init':
            if not hikari.Input.Server:
                hikari.Input.Server = 'global'
        else:
            return hikari.error('当前请求状态错误')

        url = f'{hikari_config.yuyuko_url}/public/wows/clan/rank/cw'
        params = {
            'season': hikari.Input.CwSeasonId,
            'server': hikari.Input.Server,
            'page': 1,
            'size': 100,
        }
        client_yuyuko = await get_client_yuyuko()
        resp = await client_yuyuko.get(url, params=params, timeout=10)
        result = orjson.loads(resp.content)
        hikari.Output.Yuyuko_Code = result['code']
        if result['code'] == 200 and result['data']:
            hikari.set_template_info('cw-rank.html', 1300, 100)
            result_data = {'data': result['data'], 'server': hikari.Input.Server, 'season': hikari.Input.CwSeasonId}
            return hikari.success(result_data)
        elif result['code'] == 403:
            return hikari.failed(f"{result['message']}\n请先绑定账号")
        elif result['code'] == 500:
            return hikari.failed(f"{result['message']}\n这是服务器问题，请联系雨季麻麻")
        else:
            return hikari.failed(f"{result['message']}")
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return hikari.error('请求超时了，请过会儿再尝试哦~')
    except PoolTimeout:
        await recreate_client_yuyuko()
        return hikari.error('连接池异常，请尝试重新查询~')
    except Exception:
        logger.error(traceback.format_exc())
        return hikari.error('wuwuwu出了点问题，请联系麻麻解决')
